;; Generated package description from flymake.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "flymake" "1.4.5" "A universal on-the-fly syntax checker" '((emacs "26.1") (eldoc "1.14.0") (project "0.11.1")) :commit "ab47eadb60795f2a08a4444179e395d5e34d68b1" :url "https://elpa.gnu.org/packages/flymake.html" :authors '(("Pavel Kobyakov" . "pk_at_work@yahoo.com")) :maintainer '("Spencer Baugh" . "sbaugh@janestreet.com") :keywords '("c" "languages" "tools"))
